@@ -35,7 +35,7 @@ foreach $jjj (1..12) {
 
    print "============== Running test$jjj.p ==============\n";
    %@ = ();       # Clear error status
-   do "test$jjj.p";
+   do "./test$jjj.p";
    warn $@ if $@; # Report any error detected
    if($dev eq '/PNG' && $^O =~ /mswin32/i) {
      system("ren pgplot.png pgplot_$jjj.png");
